{% extends 'corptools/character/char_base.html' %}
{% block ct_block %}
{% load colors %}
{% load l10n %}
{% load humanize  %}

<div class="col-md-12">
    <div class="row panel panel-primary">
        <div class="panel-heading text-center">Wallets</div>
        <div class="panel-body">
            <table id="wallet" class="table table-responsive">
                <thead>
                    <th>Date</th>
                    <th>Character</th>
                    <th>Type</th>
                    <th>Text</th>
                    <th>Read</th>
                </thead>
                <tbody>
                    {% for n in table_data %}
                    <tr>
                        <td class="">{{n.timestamp|date:"Y-m-d h:i:s"}}</td>
                        <td class="">{{n.character.character.character_name}}</td>
                        <td class="">{{n.notification_type}}</td>
                        <td class="">{{n.notification_text}}</td>
                        <td class="">{{n.is_read}}</td>
                    </tr>
                    {% endfor %}
                </tbody>
            </table>
        </div>
    </div>
</div>

{% endblock %}
{% block extra_javascript %}
    {% include 'bundles/datatables-js.html' %}

	<script>!function(t){function e(t){var e={columns:[],columnsIdxList:[],bootstrap:!1,autoSize:!0,label:"Filter "};if("bootstrap"in t&&"boolean"==typeof t.bootstrap&&(e.bootstrap=t.bootstrap),"autoSize"in t&&"boolean"==typeof t.autoSize&&(e.autoSize=t.autoSize),"label"in t&&"string"==typeof t.label&&(e.label=t.label),"columns"in t)for(var i=0;i<t.columns.length;i++){var n=t.columns[i];if("idx"in n&&"number"==typeof n.idx){var o=n.idx;e.columns[o]={title:null,maxWidth:null,autoSize:!0},e.columnsIdxList.push(o),"title"in n&&"string"==typeof n.title&&(e.columns[o].title=n.title),"maxWidth"in n&&"string"==typeof n.maxWidth&&(e.columns[o].maxWidth=n.maxWidth),"autoSize"in n&&"boolean"==typeof n.autoSize&&(e.columns[o].autoSize=n.autoSize)}}return e}t(document).on("preInit.dt",function(i,n){if("dt"===i.namespace){var o=new t.fn.dataTable.Api(n),a=o.table().node().id,l=o.init();if("filterDropDown"in l){var r=e(l.filterDropDown);if(0!=r.columns.length){var u=o.table().container(),s=a+"_filterWrapper",c=s+" "+(r.bootstrap?"form-inline":"");t(u).prepend('<div id="'+s+'" class="'+c+'">'+r.label+"</div>"),o.columns(r.columnsIdxList).every(function(){var e=this.index(),i=null!==r.columns[e].title?r.columns[e].title:t(this.header()).html();""==i&&(i="column "+(e+1));var n="form-control "+a+"_filterSelect",o=a+"_filterSelect"+e;t("#"+s).append('<select id="'+o+'" class="'+n+'"></select>');var l=t("#"+o).empty().append('<option value="">('+i+")</option>");})}}}}),t(document).on("init.dt",function(i,n){if("dt"===i.namespace){var o=new t.fn.dataTable.Api(n),a=o.table().node().id,l=o.init();if("filterDropDown"in l){var r=e(l.filterDropDown);o.table().container();o.columns(r.columnsIdxList).every(function(){var e=this,i=e.index(),n=t("#"+(a+"_filterSelect"+i));n.on("change",function(){var i=t.fn.dataTable.util.escapeRegex(t(this).val());e.search(i?"^"+i+"$":"",!0,!1).draw()}),e.data().unique().sort().each(function(t,e){""!=t&&n.append('<option value="'+t+'">'+t+"</option>")})})}}})}(jQuery);</script>
{% endblock %}
{% block ct_extra_script %}

    $(document).ready(function() {

        $('#wallet').DataTable({
            "filterDropDown": {
					columns: [{
						idx: 1
                            },
                            {
						idx: 2
                            }],
                    bootstrap: true
            },
            "order": [
                [0, "desc"]
            ],
            "pageLength": 50
        });
    });


    {% endblock %}
