# Generated by Django 2.2.9 on 2020-05-11 08:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0008_auto_20200511_0801'),
    ]

    operations = [
        migrations.AddField(
            model_name='characterasset',
            name='type_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='corptools.EveItemType'),
        ),
        migrations.AddField(
            model_name='corpasset',
            name='type_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to='corptools.EveItemType'),
        ),
    ]
