# Generated by Django 3.1.6 on 2021-03-22 08:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0043_auto_20210125_0758'),
    ]

    operations = [
        migrations.AddField(
            model_name='characteraudit',
            name='cache_expire_roles',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_roles',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.CreateModel(
            name='CharacterTitle',
            fields=[
                ('id', models.AutoField(auto_created=True,
                                        primary_key=True, serialize=False, verbose_name='ID')),
                ('title_id', models.IntegerField()),
                ('title', models.CharField(max_length=500)),
                ('character', models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE, to='corptools.characteraudit')),
            ],
        ),
        migrations.CreateModel(
            name='CharacterRoles',
            fields=[
                ('id', models.AutoField(auto_created=True,
                                        primary_key=True, serialize=False, verbose_name='ID')),
                ('director', models.BooleanField(default=False)),
                ('accountant', models.BooleanField(default=False)),
                ('station_manager', models.BooleanField(default=False)),
                ('personnel_manager', models.BooleanField(default=False)),
                ('character', models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE, to='corptools.characteraudit')),
            ],
        ),
    ]
