# Generated by Django 2.2.12 on 2020-05-16 10:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0011_characterwalletjournalentry_corporationwalletdivision_corporationwalletjournalentry'),
    ]

    operations = [
        migrations.CreateModel(
            name='SkillTotals',
            fields=[
                ('id', models.AutoField(auto_created=True,
                                        primary_key=True, serialize=False, verbose_name='ID')),
                ('total_sp', models.BigIntegerField()),
                ('unallocated_sp', models.IntegerField()),
                ('character', models.OneToOneField(
                    on_delete=django.db.models.deletion.CASCADE, to='corptools.CharacterAudit')),
            ],
        ),
    ]
