# Generated by Django 3.1.1 on 2021-05-31 10:25

import corptools.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0046_auto_20210427_0734'),
    ]

    operations = [
        migrations.AlterField(
            model_name='skilllist',
            name='skill_list',
            field=models.TextField(default='', null=True, validators=[
                                   corptools.validators.valid_json]),
        ),
    ]
