# Generated by Django 3.2.5 on 2021-08-08 05:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0056_auto_20210808_0414'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='titlefilter',
            options={'verbose_name': 'Smart Filter: Corporate Title checks',
                     'verbose_name_plural': 'Smart Filter: Corporate Title checks'},
        ),
    ]
