# Generated by Django 2.2.12 on 2020-07-27 00:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0016_auto_20200622_0643'),
    ]

    operations = [
        migrations.AlterField(
            model_name='characterasset',
            name='type_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='corptools.EveItemType'),
        ),
        migrations.AlterField(
            model_name='corpasset',
            name='type_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='corptools.EveItemType'),
        ),
        migrations.CreateModel(
            name='EveLocation',
            fields=[
                ('location_id', models.BigIntegerField(
                    primary_key=True, serialize=False)),
                ('location_name', models.CharField(max_length=255)),
                ('last_update', models.DateTimeField(auto_now=True)),
                ('system', models.ForeignKey(default=None, null=True,
                                             on_delete=django.db.models.deletion.SET_NULL, to='corptools.MapSystem')),
            ],
        ),
        migrations.AddField(
            model_name='characterasset',
            name='location_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='corptools.EveLocation'),
        ),
        migrations.AddField(
            model_name='corpasset',
            name='location_name',
            field=models.ForeignKey(
                default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to='corptools.EveLocation'),
        ),
    ]
